version 9.2
global stub ch1_f01
/*
	Research body fat data.
	Example to illustrate univariate FP approach.
	Predict percent body fat from BMI and other variables.
	Consider only USA females subset (also available: Jamaica, Nigeria; males).

	Graphs:
	Data and quadratic fit; smoothed residuals from quadratic.

	Note: one person with missing blood pressure was omitted in this analysis,
	giving N = 326 when full sample has 327.
*/
set more off
mvmb_load res_bodyfat
drop if msbp_missing

* Fit quadratic and show results
orthpoly bmi, degree(5) gen(O*)
regress pbfm O1 O2
predict fitfq
predict resfq, res

local y1 pbfm
local y2 fitfq
local x bmi
scatter `y1' `y2' `x', c(. l) clp(. l) sort ///
 ytitle("Percent body fat", size(large)) xlab(10(10)60) ylab(10(10)60) ///
 leg(label(1 "Observed") label(2 "Quadratic fit") ring(0) pos(5) col(1) ) ///
 ms(oh i) mcolor(gs10) msize(medium) lwidth(medthick ..) xtitle("") ///
 name(g1, replace) nodraw

* Smoothed residuals
local y1 resfq
running_ci `y1' `x'
residual_plot_cmd s_`x' ll_`x' ul_`x' `x', yl(-10) yu(10)

twoway `r(cmd1)' `r(cmd2)' ///
 (scatter `y1' `x', ytitle("Residuals and smoothed residuals", size(large)) ///
 ms(oh) mcolor(gs10) xlab(10(10)60) xtitle("") ) ///
 `r(cmd3)', name(g2, replace) nodraw

graph combine g1 g2, sav($stub, replace) b2title("bmi (body mass index)") nodraw

gph2emf $stub
gph2eps $stub

graph drop g1 g2
set more on
