version 9.2
global stub ch2_f01
/*
	Compare indexes for educational body fat data (BE(.05) vs full) by correlation plot
	and smoothed Bland-Altman plot.
*/
set more off
mvmb_load edu_bodyfat_std

global vars x01-x13

* Model 1. Full linear
qui regress pcfat $vars
predict full

* Model 2. BE(.05)
qui stepwise regress pcfat $vars, pr(.05) pe(.0499)
predict be05

twoway (scatter be05 full, ms(oh) mcolor(gs10) ) ///
(line full full, sort clp(l) lcolor(gs4) lwidth(medthick) ) ///
 , xtitle("Fitted values, full model", size(large)) ///
 ytitle("Fitted values, BE(0.05) model", size(large)) ///
 legend(off) name(g1, replace) nodraw

* ICC
icc full be05

* Bland-Altman plot with smoothing
gen diff = be05-full
gen mean = (full+be05)/2

local x mean
local y diff 
running_ci `y' `x'
residual_plot_cmd s_`x' ll_`x' ul_`x' `x', yl(-4) yu(4)

twoway `r(cmd2)' ///
 (scatter `y' `x', ms(oh) mcolor(gs12) ) `r(cmd3)' ///
  , ytitle("BE(0.05) minus full", size(large))  ///
  xtitle("(BE(0.05) + full)/2", size(large)) ///
  name(g2, replace) nodraw

local i $stub
graph combine g1 g2, sav(`i', replace) nodraw

gph2emf `i'
gph2eps `i'

graph drop g1 g2
set more on
