version 9.2
global stub ch4_f02
/*
	Schematic diagram of monotonic and non-monotonic age relationships.
*/
mvmb_load
drop _all
set obs 400
gen x = _n/(.5*_N)

gen y1 = 4*x^-2-3*log(x)
gen y2 = 4*x^-2+3*log(x)

drop if x<1

* Standardize y1 and y2 to [0,1]
foreach v of var y1 y2 {
	qui sum `v'
	replace `v' = (`v'-r(min))/(r(max)-r(min))
}
gen y2a = cond(x<1|x>1.5,.,y2)
gen y2b = cond(x<=1.5,.,y2)

* Plot on "age" in [25,75]
gen age = 25+50*(x-1)

di "Function min at age = " 25+50*(sqrt(8/3)-1)

line y1 y2a y2b age, sort clp(l - _) xline(50, lwidth(vthin) lpattern(dot)) xla(25 50 75) yla(0 1) ///
 legend(label(1 "Function 1: monotonic for all ages") label(2 "Function 2: monotonic for 25 < age < 50") ///
 label(3 "Function 2: unimodal for 50 < age < 75") ///
 ring(0) pos(1) col(1)) xtitle("age (yr)") ytitle(Log relative hazard) lwidth(medthick ..) sav($stub,replace) ///
 nodraw

gph2emf $stub
gph2eps $stub
set more on
