version 9.2
global stub ch4_f07
/*
	Research body fat data.
	Profile likelihood function for alpha in Box-Tidwell model.
	Also compare fitted curves Box-Tidwell vs FP1.

	(Note: N = 327)
*/
set more off
mvmb_load res_bodyfat
mvmb_logopen
/*
	Use -pllf- (REF), suppressing graph, to determine
	likelihood-based MLE and confidence interval.
*/
pllf regress pbfm X, formula(bmi^X) range(-1.2 -0.5) nograph
local mle = r(b)
local llci = r(l_llci)
local ulci = r(l_ulci)
local deviance = -2*r(ll)
local deviance_limit = -2*r(ll_limit)

// Plot deviances
qui {
	tempname tmp
	postfile `tmp' alpha dev using $stub, replace
	forval alpha=-1.2(0.01)-0.46 {
		fracpoly reg pbfm bmi `alpha'
		post `tmp' (`alpha') (e(fp_dev))
	}
	postclose `tmp'
	preserve
	use $stub, replace
	line dev alpha, sort xtitle(pi) ytitle(Deviance) xline(`llci' `ulci', lwidth(vthin) lpattern(dash)) ///
	 yline(`deviance_limit', lwidth(vthin) lpattern(dash)) lwidth(medthick) xla(-1.25(.25)-.5) ///
	 name(g1, replace) nodraw
	restore

	fracpoly reg pbfm bmi `mle'
	predict f1	
	fracpoly reg pbfm bmi -1
	predict f2
	line f1 f2 bmi, sort xtitle(Body mass index) ytitle("Percent body fat (fitted)") clp(l -) ///
	 legend(label(1 "Box-Tidwell") label(2 "FP1 (-1)") pos(11) ring(0) col(1)) lwidth(medthick ..) lcolor(gs4 ..) ///
	 name(g2, replace) nodraw
}
graph combine g1 g2, sav($stub, replace) nodraw

gph2emf $stub
gph2eps $stub

graph drop g1 g2
set more on
