version 9.2
global stub ch4_f08
/*
	Whitehall 1 data.
	Plot of fitted function for cigarette smoking in 2 ways.
	1. As given by fracpred (logit prob and prob).
	2. Adjusted to referent non-smokers (log OR and OR).
*/
set more off
mvmb_load whitehall1
mvmb_logopen

fracgen cigs 0, adjust(0)
logit all10 cigs_1
local x cigs

* logit probability of dying scale
predict s_`x', xb
predict se, stdp
gen ll_`x' = s_`x'-1.96*se
gen ul_`x' = s_`x'+1.96*se
residual_plot_cmd s_`x' ll_`x' ul_`x' `x', nozero yl(-3) yu(-1)
preserve
qui bysort `x': drop if _n>1
twoway `r(cmd1)' `r(cmd2)' `r(cmd3)' ///
 , xtitle("") ytitle("Logit prob(death)") xla(0(10)60) ///
 name(g1, replace) nodraw
restore

* probability scale
foreach v in s ll ul {
	qui replace `v'_`x' = invlogit(`v'_`x')
}
residual_plot_cmd s_`x' ll_`x' ul_`x' `x', nozero yl(.05) yu(.25)
preserve
qui bysort `x': drop if _n>1
twoway `r(cmd1)' `r(cmd2)' `r(cmd3)' ///
 , xtitle("") ytitle("Prob(death)") xla(0(10)60) ///
 name(g2, replace) nodraw
restore

/////////////////////////////////////////////////////////////////////////////////////
* ln OR, adjusted to 0 cigs
drop se s_`x' ll_`x' ul_`x'

xpredict s_`x', with(cigs_1)
xpredict se, with(cigs_1) stdp
gen ll_`x' = s_`x'-1.96*se
gen ul_`x' = s_`x'+1.96*se
residual_plot_cmd s_`x' ll_`x' ul_`x' `x', nozero yl(0) yu(1.5)
preserve
qui bysort `x': drop if _n>1
twoway `r(cmd1)' `r(cmd2)' `r(cmd3)' ///
 , xtitle("") ytitle("Log OR") xla(0(10)60) ///
 name(g3, replace) nodraw
restore

* OR scale
foreach v in s ll ul {
	qui replace `v'_`x' = exp(`v'_`x')
}
residual_plot_cmd s_`x' ll_`x' ul_`x' `x', nozero yl(1) yu(4)
preserve
qui bysort `x': drop if _n>1
twoway `r(cmd1)' `r(cmd2)' `r(cmd3)' ///
 , xtitle("") ytitle("OR") xla(0(10)60) ///
 name(g4, replace) nodraw
restore

graph combine g1 g2 g3 g4, nodraw ///
 imargin(small) b2title("cigs (cigarettes/day)") sav($stub, replace)

gph2emf $stub
gph2eps $stub

graph drop g1 g2 g3 g4
set more on
