version 9.2
global stub ch5_f07
/*
	Educational body fat data.
	(a) linear fit after g_delta(X) transformation.
	(b) Leave one out deviance plot.
*/
set more off
mvmb_load edu_bodyfat
qui {
	* Take care with transformation when extending ab for plotting purposes.
	sum ab
	local mean = r(mean)
	local sd = r(sd)
	local lower = `mean'-2.8*`sd'
	local upper = `mean'+2.8*`sd'
	noi di "upper = " `upper'
	gen x = (ab-`mean')/`sd'
	set obs 274
	replace ab = _n-126 in 253/274
	set obs 275
	replace ab = 122.7 in l	// eta to hit the upper truncation point, making the corner plot correctly
	replace x = (ab-`mean')/`sd' in 253/l
	
	gdelta gx = x, nostandardize

	gen byte case39 = (case==39)

	regress pcfat gx
	predict fit1

	* Truncate at mean + 2.8sd and fit linear
	gen xtrunc = cond(ab>=`upper', (`upper'-`mean')/`sd', x)
	regress pcfat xtrunc if ab<=`upper'
	predict fit2
}
global stuff1 clp(l -) sort ylab(0(20)60) xlab(70(20)150) xsca(r(60 150)) ///
 xline(`lower' `upper', lwidth(vthin) lpattern(dash))

twoway scatter pcfat ab, ms(oh) || line fit1 fit2 ab, $stuff1 ///
 ytitle("Percentage bodyfat") xtitle("Abdominal circumference (ab)") ///
 leg(label(2 "Linear on g_delta(ab)") label(3 "ab truncated at 122.7 cm") order(2 3) col(1) ring(0) pos(11)) ///
 text(34 148 "Case 39", place(sw)) name(g1, replace) nodraw

/*
	Body fat data: deviance for FP2 on leave one out, for gdelta(ab)
*/

fpdiagnostic regress pcfat gx using $stub, case

preserve

use $stub, replace

gen devdif = devlin-devfp2

scatter devdif case, xlab(0(100)200 39) xsca(r(0 252)) ylab(0(2)6 7.81) ///
 yline(7.81, lwidth(vthin) lpattern(dash)) xline(39, lwidth(vthin) lpattern(dash)) ///
 xtitle("Case number") ytitle("Deviance difference, FP2 vs linear") ///
 ysca(r(0 8)) ms(oh) name(g2, replace) nodraw

* Detect most influential obs
sum case devdif if devdif>3

restore

graph combine g1 g2, sav($stub, replace) nodraw

gph2emf $stub
gph2eps $stub

graph drop g1 g2
set more on
