version 9.2
global stub ch6_f16
/*
	Diabetes data.
	Plots of smoothed residuals for 3 models.
*/
set more off
mvmb_load diabetes
mvmb_logopen

// Model 1: linear
regress cpep age base
predict r1, res

// Model 2: select FP1
mfp regress cpep age base, dfd(2)
predict r2, res

// Model 3: best FP1
qui mfp regress cpep age base, dfd(2) alpha(1)
predict r3, res

local k 0
global gph
forval j=1/3 {
	local title "Model `j'"
	foreach x of var age base {
		local ++k

		running_ci r`j' `x'

		residual_plot_cmd s_`x' ll_`x' ul_`x' `x', yl(-2) yu(2)

		twoway `r(cmd1)' `r(cmd2)' ///
		 (scatter r`j' `x', ms(oh) mcolor(gs12) ) ///
		`r(cmd3)' ///
		 , title(`"`title'"') xtitle("`x'", size(large)) ytitle(" ") ///
		 name(g`k', replace) nodraw
		global gph $gph g`k'
		local title " "
	}
}
log close
graph combine $gph, ycommon l1title("Residuals") ///
 sav($stub, replace) colfirst imargin(tiny) nodraw

gph2emf $stub
gph2eps $stub

graph drop $gph
set more on
