version 9.2
global stub ch6_t05
/*
	Prostate data.
	Interest in effect of a single predictor (cp).
	Statistics for 3 models:

	1. Unadjusted linear, FP1, FP2.
	2. Linear, FP1, FP2 with linear adjustment model, latter selected at .2 level independently of cp.
	3. Linear, FP1, FP2 with MFP adjustment model, latter selected at .2 level independently of cp.

	Outcome: lpsa. "Corrected" prostate weight used.
	Ignoring gleason beccause almost 100% correlated with pgg45
*/
set more off
mvmb_load prostate_ca
mvmb_logopen

gen lcavol = ln(cavol)

global adjlin cavol weight svi pgg45 bph
global adjmfp lcavol weight svi

* model 1: linear, FP1, FP2; best model by FSP with alpha=0.1
mfp regress lpsa cp, select(.999) alpha(.999) df(1)
mfp regress lpsa cp, select(.999) alpha(.999) df(2)
mfp regress lpsa cp, select(.999) alpha(.999) df(4)
mfp regress lpsa cp, select(.999) alpha(.1)  df(4)

* model 2: linear, FP1, FP2; best model by FSP with alpha=0.1, 
* adjustment model linear, fixed from outside (vars selected at .2 level)
mfp regress lpsa cp $adjlin, select(.999) alpha(.999) df(1, cp:1)
mfp regress lpsa cp $adjlin, select(.999) alpha(.999) df(1, cp:2)
mfp regress lpsa cp $adjlin, select(.999) alpha(.999) df(1, cp:4)
mfp regress lpsa cp $adjlin, select(.999) alpha(.999, cp:.1)  df(1, cp:4)

* model 3: linear, FP1, FP2; best model by FSP with alpha=0.1,
* adjustment model MFP, fixed from outside (vars selected at .2 level, functions at .05 level)
mfp regress lpsa cp $adjmfp, select(.999) alpha(.999) df(1, cp:1)
mfp regress lpsa cp $adjmfp, select(.999) alpha(.999) df(1, cp:2)
mfp regress lpsa cp $adjmfp, select(.999) alpha(.999) df(1, cp:4)
mfp regress lpsa cp $adjmfp, select(.999) alpha(.999, cp:.1)  df(1, cp:4)

log close
set more on
