version 9.2
global stub ch7_f10
/*
	Kidney cancer data.
	20 example curves from most complex situation: select adjustment model with mfpi.
*/
set more off
mvmb_load
use mfpicurves, replace
egen mean = rmean(d*)
egen sd = rsd(d*)
gen low = mean-1.96*sd
gen high = mean+1.96*sd

global stuff lcolor(gs8 ..) xlab(5(5)20) xscale(r(2.5 20)) ///
 leg(off) xtitle(" ") ytitle(" ") ///
 yline(0, lwidth(thin) lcolor(gs12) lpattern(shortdash)) sort

// Plot 20 curves
line d611_1-d801_1 wcc if wcc<=20, $stuff ///
 name(g1, replace) nodraw

* Include results from stepp with tail g = 6.
gen int o = _n
local g 6
stepp_tail stcox wcc, gen(S) with(trt) g(`g') sort(o)

* Include original mfpi results
fracgen t_mt -0.5
fracgen haem -1
mfpi stcox t_mt_1 haem_1 whod1 whod2, ///
 df(1) select(1) fp2(Gwcc) with(trt) gendiff(dorig) sediff
gen lorig = dorig1_1-2*dorig1s_1
gen horig = dorig1_1+2*dorig1s_1

twoway ///
 (scatter Sb Smean) ///
 (line dorig1_1 lorig horig mean low high wcc if wcc<=20, sort clp(l l l - - -) ///
 lwidth(medthick medthin medthin medthick medthin medthin) lcolor(gs4 gs6 gs6 gs4 gs6 gs6) ) ///
 , xlab(5(5)20) xtitle(" ") ytitle(" ") ///
 leg(order(1 2 5) label(1 "STEPP (tail-oriented)") label(2 "MFPI + 95% CI") ///
 label(5 "Bootstrap + 95% CI") ring(0) pos(5) col(1)) ///
 yline(0, lwidth(thin) lcolor(gs12) lpattern(shortdash)) ///
 name(g2, replace) nodraw

graph combine g1 g2, ycommon sav($stub, replace) ///
 l1title("Treatment effect, log relative hazard") b2title("White cell count")

gph2emf $stub
gph2emf $stub

graph drop g1 g2
set more on
